---
name: 🐛 Bug Report
about: Report an issue to help us improve
title: '[BUG]'
labels: 'kind/bug'
assignees: ''
---
**Description**
<!-- A brief description of the issue. -->

**Expected Behavior**
<!-- A brief description of what you expected to happen. -->

**Screenshots**
<!-- Add screenshots, if applicable, to help explain your problem. -->

**Environment:**
- Host OS: 
- Browser: 

---


[Optional] **Additional Context**
<!-- Add any other context about the problem here. -->

---